@@ -11,7 +11,7 @@
 #undef PL_SUPPORT_BMP
 #undef PL_SUPPORT_TIFF
 #undef PL_SUPPORT_PICT
-#ifdef _WINDOWS
+#ifdef _WIN32
   #define PL_SUPPORT_WEMF
 #endif
 #undef PL_SUPPORT_PCX
