@@ -1,7 +1,7 @@
 /*
 /--------------------------------------------------------------------
 |
-|      $Id: plfilterfliprgb.h,v 1.2 2004/06/06 12:56:38 uzadow Exp $
+|      $Id: plfilterfliprgb.h,v 1.3 2004/06/20 16:59:38 uzadow Exp $
 |
 |      Copyright (c) 1996-2002 Ulrich von Zadow
 |
@@ -15,17 +15,17 @@
 #pragma once
 #endif // _MSC_VER >= 1000
 
-#include "plfilter.h"
+#include "plinplacefilter.h"
 
 class PLBmp;
 
 //! Filter that flips the R and B components of a bitmap.
-class PLFilterFlipRGB : public PLFilter
+class PLFilterFlipRGB : public PLInPlaceFilter
 {
 public:
   PLFilterFlipRGB();
   virtual ~PLFilterFlipRGB();
-  virtual void ApplyInPlace(PLBmp * pBmp) const;
+  virtual void ApplyInPlace(PLBmpBase * pBmp) const;
 
 private:
 };
@@ -36,6 +36,9 @@ private:
 /--------------------------------------------------------------------
 |
 |      $Log: plfilterfliprgb.h,v $
+|      Revision 1.3  2004/06/20 16:59:38  uzadow
+|      Added PLBmpBase::CopyPixels() and PLInPlaceFilter
+|
 |      Revision 1.2  2004/06/06 12:56:38  uzadow
 |      Doxygenified documentation.
 |
