@@ -1,7 +1,7 @@
 /*
 /--------------------------------------------------------------------
 |
-|      $Id: plfilterquantize.cpp,v 1.10 2004/06/15 10:26:13 uzadow Exp $
+|      $Id: plfilterquantize.cpp,v 1.12 2004/09/11 12:41:36 uzadow Exp $
 |
 |      Copyright (c) 1996-2002 Ulrich von Zadow
 |
@@ -28,7 +28,6 @@
 \--------------------------------------------------------------------
 */
 
-#include "plstdpch.h"
 #include "plfilterquantize.h"
 #include "plbitmap.h"
 #include "plexcept.h"
@@ -71,8 +70,8 @@ void PLFilterQuantize::Apply(PLBmpBase * pBmpSource, PLBmp * pBmpDest) const
   // Only works for 32 bpp bitmaps.
   PLASSERT (pBmpSource->GetBitsPerPixel() == 32);
 
-  pBmpDest->Create (pBmpSource->GetWidth(), pBmpSource->GetHeight(), 8,
-                    false, false, NULL, 0, 
+  pBmpDest->Create (pBmpSource->GetWidth(), pBmpSource->GetHeight(), 
+                    PLPixelFormat::I8, NULL, 0, 
                     pBmpSource->GetResolution());
 
   if (m_DitherPaletteType != PLDTHPAL_DEFAULT &&
@@ -1005,6 +1004,12 @@ int PLFilterQuantize::colorDist (PLPixel32 c0, PLPixel32 c1) const
 /--------------------------------------------------------------------
 |
 |      $Log: plfilterquantize.cpp,v $
+|      Revision 1.12  2004/09/11 12:41:36  uzadow
+|      removed plstdpch.h
+|
+|      Revision 1.11  2004/09/09 16:52:45  artcom
+|      refactored PixelFormat
+|
 |      Revision 1.10  2004/06/15 10:26:13  uzadow
 |      Initial nonfunctioning version of plbmpbase.
 |
