@@ -1,7 +1,7 @@
 /*
 /--------------------------------------------------------------------
 |
-|      $Id: plbmpdec.cpp,v 1.11 2003/10/14 21:12:41 uzadow Exp $
+|      $Id: plbmpdec.cpp,v 1.14 2004/09/11 12:41:35 uzadow Exp $
 |      Windows Bitmap Decoder Class
 |
 |      Windows bitmap file decoder. Decodes 1, 4, 8, 24 and 32 bpp
@@ -13,7 +13,6 @@
 \--------------------------------------------------------------------
 */
 
-#include "plstdpch.h"
 #include "plbmpdec.h"
 #include "plexcept.h"
 
@@ -33,15 +32,17 @@ PLBmpDecoder::~PLBmpDecoder
 void PLBmpDecoder::Open (PLDataSource * pDataSrc)
 {
   m_pBMI = getInfoHeader (pDataSrc, &m_Pal[0]);
-
-  int DestBPP = m_pBMI->biBitCount;
-  bool bAlpha = false;
-  if (DestBPP == 32)
-    bAlpha = true;
-  if (DestBPP > 8)
-    DestBPP = 32;
-  if (DestBPP < 8)
-    DestBPP = 8;
+  
+  PLPixelFormat pf;
+  if (m_pBMI->biBitCount <= 8) {
+    pf = PLPixelFormat::I8;
+  } else {
+    if (m_pBMI->biBitCount == 32) {
+      pf = PLPixelFormat::A8R8G8B8;
+    } else {
+      pf = PLPixelFormat::X8R8G8B8;
+    }
+  }
 
   PLPoint DPI(0,0);
   if (m_pBMI->biXPelsPerMeter > 0)
@@ -53,54 +54,43 @@ void PLBmpDecoder::Open (PLDataSource * pDataSrc)
   if (DPI.y <= 1)
     DPI.y = 0;
 
-  SetBmpInfo (PLPoint (m_pBMI->biWidth, m_pBMI->biHeight), DestBPP, DPI, bAlpha, false);
+  SetBmpInfo (PLPoint (m_pBMI->biWidth, m_pBMI->biHeight), 
+        DPI, pf);
 }
 
-void PLBmpDecoder::GetImage (PLBmp & Bmp)
+void PLBmpDecoder::GetImage (PLBmpBase & Bmp)
 {
-  if (m_bpp == 8)
+  if (GetBitsPerPixel() == 8)
     Bmp.SetPalette (&m_Pal[0]);
 
-  Bmp.Lock(false, true);
-
-  try
+  switch (m_pBMI->biBitCount)
   {
-    switch (m_pBMI->biBitCount)
-    {
-      case 1:
-        decode1bpp (m_pDataSrc, &Bmp);
-        break;
-      case 4:
-        if (m_pBMI->biCompression == BI_RGB)
-          decode4bpp (m_pDataSrc, &Bmp);
-         else
-          decodeRLE4 (m_pDataSrc, &Bmp);
-        break;
-      case 8:
-        if (m_pBMI->biCompression == BI_RGB)
-          decode8bpp (m_pDataSrc, &Bmp);
-         else
-          decodeRLE8 (m_pDataSrc, &Bmp);
-        break;
-      case 16:
-        decodeHiColor (m_pDataSrc, &Bmp, m_pBMI);
-        break;
-      case 24:
-      case 32:
-        decodeTrueColor (m_pDataSrc, &Bmp, m_pBMI->biBitCount);
-        break;
-      default:
-        // This is not a standard bmp file.
-        raiseError (PL_ERRFORMAT_UNKNOWN,
-                    "Decoding bmp: Illegal bpp value.");
-    }
-
-    Bmp.Unlock();
-  }
-  catch (...)
-  {
-    Bmp.Unlock();
-    throw;
+    case 1:
+      decode1bpp (m_pDataSrc, &Bmp);
+      break;
+    case 4:
+      if (m_pBMI->biCompression == BI_RGB)
+        decode4bpp (m_pDataSrc, &Bmp);
+        else
+        decodeRLE4 (m_pDataSrc, &Bmp);
+      break;
+    case 8:
+      if (m_pBMI->biCompression == BI_RGB)
+        decode8bpp (m_pDataSrc, &Bmp);
+        else
+        decodeRLE8 (m_pDataSrc, &Bmp);
+      break;
+    case 16:
+      decodeHiColor (m_pDataSrc, &Bmp, m_pBMI);
+      break;
+    case 24:
+    case 32:
+      decodeTrueColor (m_pDataSrc, &Bmp, m_pBMI->biBitCount);
+      break;
+    default:
+      // This is not a standard bmp file.
+      raiseError (PL_ERRFORMAT_UNKNOWN,
+                  "Decoding bmp: Illegal bpp value.");
   }
 }
 
@@ -236,7 +226,7 @@ WINBITMAPINFOHEADER * PLBmpDecoder::getInfoHeader
 
 void PLBmpDecoder::decode1bpp
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp
+      PLBmpBase * pBmp
     )
     // Decodes a 2-color bitmap. Ignores the palette & just uses
     // black & white as 'colors' if decoding to 32 bit
@@ -306,7 +296,7 @@ void PLBmpDecoder::decode1bpp
 
 void PLBmpDecoder::decode4bpp
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp
+      PLBmpBase * pBmp
     )
     // Decodes an uncompressed 16-color-bitmap.
 {
@@ -354,7 +344,7 @@ void PLBmpDecoder::decode4bpp
 
 void PLBmpDecoder::decode8bpp
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp
+      PLBmpBase * pBmp
     )
     // Decodes an uncompressed 256-color-bitmap.
 {
@@ -389,7 +379,7 @@ void PLBmpDecoder::decode8bpp
 
 void PLBmpDecoder::decodeRLE4
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp
+      PLBmpBase * pBmp
     )
     // Decodes a compressed 16-color-bitmap.
 {
@@ -491,7 +481,7 @@ void PLBmpDecoder::decodeRLE4
 
 void PLBmpDecoder::decodeRLE8
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp
+      PLBmpBase * pBmp
     )
     // Decodes a compressed 256-color-bitmap.
 {
@@ -557,7 +547,7 @@ void PLBmpDecoder::decodeRLE8
 
 void PLBmpDecoder::decodeHiColor
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp,
+      PLBmpBase * pBmp,
       WINBITMAPINFOHEADER * pBMI
     )
 {
@@ -584,7 +574,7 @@ void PLBmpDecoder::decodeHiColor
 
 void PLBmpDecoder::decodeTrueColor
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp,
+      PLBmpBase * pBmp,
       int SrcBPP
     )
     // Decodes true-color bitmap
@@ -622,7 +612,7 @@ void PLBmpDecoder::decodeTrueColor
 
 void PLBmpDecoder::decode15bppLine
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp,
+      PLBmpBase * pBmp,
       PLBYTE * pDest
     )
 {
@@ -646,7 +636,7 @@ void PLBmpDecoder::decode15bppLine
 
 void PLBmpDecoder::decode16bppLine
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp,
+      PLBmpBase * pBmp,
       PLBYTE * pDest
     )
 {
@@ -671,7 +661,7 @@ void PLBmpDecoder::decode16bppLine
 
 void PLBmpDecoder::decode24bppLine
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp,
+      PLBmpBase * pBmp,
       PLBYTE * pDest
     )
 {
@@ -695,7 +685,7 @@ void PLBmpDecoder::decode24bppLine
 
 void PLBmpDecoder::decode32bppLine
     ( PLDataSource * pDataSrc,
-      PLBmp * pBmp,
+      PLBmpBase * pBmp,
       PLBYTE * pDest
     )
 {
@@ -748,6 +738,15 @@ int PLBmpDecoder::readPalette
 /--------------------------------------------------------------------
 |
 |      $Log: plbmpdec.cpp,v $
+|      Revision 1.14  2004/09/11 12:41:35  uzadow
+|      removed plstdpch.h
+|
+|      Revision 1.13  2004/09/09 16:52:49  artcom
+|      refactored PixelFormat
+|
+|      Revision 1.12  2004/06/19 16:49:07  uzadow
+|      Changed GetImage so it works with PLBmpBase
+|
 |      Revision 1.11  2003/10/14 21:12:41  uzadow
 |      Changed palette handling of 4 bpp bmp files if biClrUsed is != 0.
 |      Now it doesn't do what the docs say. Instead, it does what other programs
