@@ -1,17 +1,15 @@
 /*
 /--------------------------------------------------------------------
 |
-|      $Id: plobject.cpp,v 1.4 2002/03/31 13:36:42 uzadow Exp $
+|      $Id: plobject.cpp,v 1.5 2004/09/11 12:41:35 uzadow Exp $
 |
 |      Copyright (c) 1996-2002 Ulrich von Zadow
 |
 \--------------------------------------------------------------------
 */
 
-#include "plstdpch.h"
 #include "plobject.h"
 
-
 PLObject::PLObject()
 {
 
@@ -30,6 +28,9 @@ void PLObject::AssertValid() const
 /--------------------------------------------------------------------
 |
 |      $Log: plobject.cpp,v $
+|      Revision 1.5  2004/09/11 12:41:35  uzadow
+|      removed plstdpch.h
+|
 |      Revision 1.4  2002/03/31 13:36:42  uzadow
 |      Updated copyright.
 |
