@@ -1,7 +1,7 @@
 /*
 /--------------------------------------------------------------------
 |
-|      $Id: plpictdec.cpp,v 1.10 2002/11/04 21:03:12 uzadow Exp $
+|      $Id: plpictdec.cpp,v 1.14 2004/10/02 22:23:12 uzadow Exp $
 |      Macintosh pict Decoder Class
 |
 |      This class decodes macintosh PICT files with 1,2,4,8,16 and 32
@@ -16,7 +16,6 @@
 \--------------------------------------------------------------------
 */
 
-#include "plstdpch.h"
 #include "config.h"
 #include "plpictdec.h"
 #ifdef PL_SUPPORT_JPEG
@@ -59,7 +58,7 @@ void PLPictDecoder::Open (PLDataSource * pDataSrc)
 
 
 //! Fills the bitmap with the image.
-void PLPictDecoder::GetImage (PLBmp & Bmp)
+void PLPictDecoder::GetImage (PLBmpBase & Bmp)
 {
   switch (m_PictType)
   {
@@ -82,28 +81,6 @@ void PLPictDecoder::GetImage (PLBmp & Bmp)
 }
 
 
-/*
-void PLPictDecoder::DoDecode
-    ( PLBmp * pBmp,
-      PLDataSource * pDataSrc
-    )
-    // Called by MakeDIB to do the actual decoding.
-{
-  int Version;
-
-  Trace (2, "Decoding mac pict.\n");
-
-  // Skip empty 512 byte header.
-  pDataSrc->Skip (512);
-
-  // Read PICT header
-  readHeader (pDataSrc, Version);
-
-  interpretOpcodes (pBmp, pDataSrc, Version);
-  pBmp->SetResolution (m_Resolution);
-}
-*/
-
 void PLPictDecoder::readHeader
     ( PLDataSource * pDataSrc,
       int& Version
@@ -122,7 +99,7 @@ void PLPictDecoder::readHeader
 
   while ((ch = ReadByte(pDataSrc)) == 0);
   if (ch != 0x11)
-                raiseError (PL_ERRWRONG_SIGNATURE,
+    raiseError (PL_ERRWRONG_SIGNATURE,
                 "Error decoding pict: Version number missing.");
 
   switch (ReadByte(pDataSrc))
@@ -249,7 +226,7 @@ void PLPictDecoder::interpretOpcodes
       Trace (2, sz);
     }
     else if ((Opcode >= 0xd0 && Opcode <= 0xfe) ||
-             (Opcode >= 8100 && Opcode <= 0xffff))
+             Opcode >= 8100)
     {
       sprintf (sz, "Opcode: reserved 0x%x.\n", Opcode);
       Trace (2, sz);
@@ -405,12 +382,10 @@ void PLPictDecoder::opcode9a
 }
 
 void PLPictDecoder::DecodeOp9a
-    ( PLBmp * pBmp,
+    ( PLBmpBase * pBmp,
       PLDataSource * pDataSrc
     )
 {
-  pBmp->Lock(false, true);
-
   // Do the actual unpacking.
   switch (m_PixMap.pixelSize)
   {
@@ -423,7 +398,6 @@ void PLPictDecoder::DecodeOp9a
     default:
       unpackbits (&m_PixMap.Bounds, 0, m_PixMap.pixelSize, pBmp, pDataSrc);
   }
-  pBmp->Unlock();
 }
 
 void PLPictDecoder::longComment
@@ -494,7 +468,7 @@ void PLPictDecoder::jpegOp
 }
 
 void PLPictDecoder::DecodeJPEG
-    ( PLBmp * pBmp,
+    ( PLBmpBase * pBmp,
       PLDataSource * pDataSrc
     )
 {
@@ -514,19 +488,19 @@ void PLPictDecoder::setBmpInfo
     ( MacpixMap PixMap
     )
 {
-  int DestBPP;
-  if (PixMap.pixelSize > 8)
-    DestBPP = 32;
+    
+  PLPixelFormat pf;
+  if (PixMap.pixelSize > 8)  
+    if (PixMap.cmpCount == 4)
+        pf = PLPixelFormat::A8R8G8B8;
+     else 
+       pf = PLPixelFormat::X8R8G8B8;
   else
-    DestBPP = 8;
+    pf = PLPixelFormat::I8;
 
-  bool bAlpha = false;
-  // Create empty DIB
-  if (DestBPP == 32 && PixMap.cmpCount == 4)
-    bAlpha = true;
   SetBmpInfo (PLPoint (PixMap.Bounds.right - PixMap.Bounds.left,
                        PixMap.Bounds.bottom - PixMap.Bounds.top),
-              DestBPP, PLPoint (PixMap.hRes, PixMap.vRes), bAlpha, false);
+              PLPoint (PixMap.hRes, PixMap.vRes), pf);
 }
 
 
@@ -550,12 +524,12 @@ void PLPictDecoder::doBitmap
   width = m_Bounds.right - m_Bounds.left;
   height = m_Bounds.bottom - m_Bounds.top;
 
-  SetBmpInfo (PLPoint (width, height), 8, PLPoint (0,0), false, false);
+  SetBmpInfo (PLPoint (width, height), PLPoint (0,0), PLPixelFormat::I8);
   m_PictType = bitmap;
 }
 
 void PLPictDecoder::DecodeBitmap
-    ( PLBmp * pBmp,
+    ( PLBmpBase * pBmp,
       PLDataSource * pDataSrc
     )
 {
@@ -564,12 +538,9 @@ void PLPictDecoder::DecodeBitmap
   if (m_bIsRegion)
     skipPolyOrRegion (pDataSrc);
 
-  pBmp->Lock(false, true);
   pBmp->SetPaletteEntry (0, 0, 0, 0, 255);
   pBmp->SetPaletteEntry (1, 255, 255, 255, 255);
   unpackbits (&m_Bounds, m_rowBytes, 1, pBmp, pDataSrc);
-
-  pBmp->Unlock();
 }
 
 
@@ -586,7 +557,7 @@ void PLPictDecoder::doPixmap
 }
 
 void PLPictDecoder::DecodePixmap
-    ( PLBmp * pBmp,
+    ( PLBmpBase * pBmp,
       PLDataSource * pDataSrc
     )
 {
@@ -607,7 +578,6 @@ void PLPictDecoder::DecodePixmap
   if (m_bIsRegion)
     skipPolyOrRegion (pDataSrc);
 
-  pBmp->Lock(false, true);
   switch (m_PixMap.pixelSize)
   {
     case 32:
@@ -620,14 +590,13 @@ void PLPictDecoder::DecodePixmap
       unpackbits (&m_PixMap.Bounds, m_rowBytes, m_PixMap.pixelSize,
                   pBmp, pDataSrc);
   }
-  pBmp->Unlock();
 }
 
 void PLPictDecoder::unpack32bits
     ( MacRect* pBounds,
       PLWORD rowBytes,
       int NumBitPlanes,    // 3 if RGB, 4 if RGBA
-      PLBmp * pBmp,
+      PLBmpBase * pBmp,
       PLDataSource * pDataSrc
     )
     // This routine decompresses BitsRects with a packType of 4 (and
@@ -712,7 +681,7 @@ void PLPictDecoder::unpack32bits
 void PLPictDecoder::unpack8bits
     ( MacRect* pBounds,
       PLWORD rowBytes,
-      PLBmp * pBmp,
+      PLBmpBase * pBmp,
       PLDataSource * pDataSrc
     )
     // Decompression routine for 8 bpp. rowBytes is the number of
@@ -762,7 +731,7 @@ void PLPictDecoder::unpackbits
     ( MacRect* pBounds,
       PLWORD rowBytes,
       int pixelSize,         // Source bits per pixel.
-      PLBmp * pBmp,
+      PLBmpBase * pBmp,
       PLDataSource * pDataSrc
     )
     // Decompression routine for everything but 8 & 32 bpp. This
@@ -1224,6 +1193,18 @@ void PLPictDecoder::tracePixMapHeader
 /--------------------------------------------------------------------
 |
 |      $Log: plpictdec.cpp,v $
+|      Revision 1.14  2004/10/02 22:23:12  uzadow
+|      - configure and Makefile cleanups\n- Pixelformat enhancements for several filters\n- Added PLBmpBase:Dump\n- Added PLBmpBase::GetPixelNn()-methods\n- Changed default unix byte order to BGR
+|
+|      Revision 1.13  2004/09/11 12:41:35  uzadow
+|      removed plstdpch.h
+|
+|      Revision 1.12  2004/09/09 16:52:49  artcom
+|      refactored PixelFormat
+|
+|      Revision 1.11  2004/06/19 16:49:07  uzadow
+|      Changed GetImage so it works with PLBmpBase
+|
 |      Revision 1.10  2002/11/04 21:03:12  uzadow
 |      Fixed error when PL_SUPPORT_JPEG was turned off.
 |
