@@ -1,7 +1,7 @@
 /*
 /--------------------------------------------------------------------
 |
-|      $Id: pltester.cpp,v 1.64 2004/06/15 14:17:25 uzadow Exp $
+|      $Id: pltester.cpp,v 1.74 2004/11/09 15:55:06 artcom Exp $
 |
 |      Copyright (c) 1996-2002 Ulrich von Zadow
 |
@@ -47,13 +47,14 @@
 #include "pltestdecoders.h"
 #include "pltestcountedpointer.h"
 #include "pltestfilters.h"
+#include "pltestpixelformat.h"
 
 #include <typeinfo>
 #include <iostream>
 #include <string>
 #include <fstream>
 
-#ifdef _WINDOWS
+#ifdef _WIN32
 #include "../../win/test/resource.h"
 #endif
 
@@ -82,6 +83,11 @@ void PLTester::RunTests ()
   try
   {
 
+    cerr << "Testing PixelFormats..\n";
+    PLTestPixelFormat pltf;
+    pltf.RunTests();
+    AggregateStatistics(pltf);
+
     cerr << "Testing Bmp classes...\n";
     cerr << "  Testing PLBmpInfo...\n";
     testBmpInfo (m_AnyBmp32);
@@ -97,77 +103,7 @@ void PLTester::RunTests ()
     cerr << "  Testing 8 bpp PLAnyBmp...\n";
     testPLBmp (m_AnyBmp8);
 
-#ifdef PL_SUPPORT_SDL
-    {
-      cerr << "  Testing 32 bpp PLSDLBmp...\n";
-      testPLBmp(m_SDLBmp);
-      testPLSDLBmp();
-    }
-#endif    
-
-#ifdef PL_SUPPORT_DFB
-    {
-      cerr << "  Testing DirectFB support...\n";
-      IDirectFB * pDirectFB;
-      int argc = 2;
-      char ** argv = new (char *)[4];
-      argv[0] = strdup ("bogus_appname");
-      argv[1] = strdup ("--dfb:force-windowed");
-      DFBResult err;
-      cerr << "    Testing DirectFBInit...\n";
-      err = DirectFBInit (&argc, &argv);
-      Test (err == DFB_OK);
-      Test (argc == 1);
-      cerr << "    Testing DirectFBCreate...\n";
-      err = DirectFBCreate (&pDirectFB);
-      if (err == DFB_OK)
-      {
-        cerr << "    Testing SetDirectFB...\n";
-        PLDirectFBBmp::SetDirectFB(pDirectFB);
-        
-        m_pDirectFBBmp = new PLDirectFBBmp;
-        cerr << "    Testing 32 bpp PLDirectFBBmp...\n";
-        m_pDirectFBBmp->Create (20, 20, 32, false, false);
-        testPLBmp(*m_pDirectFBBmp);
-        cerr << "    Testing 32 bpp PLDirectFBBmp with alpha...\n";
-        m_pDirectFBBmp->Create (20, 20, 32, true, false);
-        testPLBmp(*m_pDirectFBBmp);
-        cerr << "    Testing 16 bpp PLDirectFBBmp...\n";
-        m_pDirectFBBmp->Create (20, 20, 16, false, false);
-        testPLBmp(*m_pDirectFBBmp);
-        cerr << "    Testing 8 bpp PLDirectFBBmp...\n";
-        m_pDirectFBBmp->Create (20, 20, 8, false, false);
-        testPLBmp(*m_pDirectFBBmp);
-        
-        cerr << "    Testing CreateFromSurface...\n";
-        IDirectFBSurface * pSurface;
-        DFBSurfaceDescription Desc;
-        Desc.flags = DFBSurfaceDescriptionFlags (DSDESC_CAPS | DSDESC_WIDTH | 
-                DSDESC_HEIGHT | DSDESC_PIXELFORMAT);
-        Desc.caps = DSCAPS_SYSTEMONLY;
-        Desc.width = 128;
-        Desc.height = 128;
-        Desc.pixelformat = DSPF_ARGB;
-        DFBResult err = pDirectFB->CreateSurface(pDirectFB, &Desc, 
-                &pSurface);
-        Test(err == 0);
-        m_pDirectFBBmp->CreateFromSurface(pSurface, false);
-   
-        cerr << "    Deleting Bmp...\n";
-        delete m_pDirectFBBmp;
-        pSurface->Release(pSurface);
-        
-        cerr << "    Release DirectFB handle...\n";
-        pDirectFB->Release(pDirectFB);
-        cerr << "    End...\n";
-      }
-      else
-      {
-        cerr << "    Skipping DirectFB tests (root access?)\n";
-      }
-    }
-#endif
-#ifdef _WINDOWS
+#ifdef _WIN32
     cerr << "  Testing 32 bpp PLDIBSection...\n";
     testPLBmp (m_DIBSect32);
     testPLWinBmp (m_DIBSect32);
@@ -189,7 +125,7 @@ void PLTester::RunTests ()
     SubBmp32.Create(m_AnyBmp32, PLRect(0, 0, 5, 5));
     testBmpBase(SubBmp32);
     PLSubBmp SubBmp32_Raw;
-    SubBmp32_Raw.Create(16, 16, 32, true, TempBytes, 128);
+    SubBmp32_Raw.Create(16, 16, PLPixelFormat::A8R8G8B8, TempBytes, 128);
     testBmpBase(SubBmp32_Raw);
     
     cerr << "  Testing 24 bpp PLSubBmp...\n";
@@ -197,7 +133,7 @@ void PLTester::RunTests ()
     SubBmp24.Create(m_AnyBmp24, PLRect(1, 1, 4, 4));
     testBmpBase(SubBmp24);
     PLSubBmp SubBmp24_Raw;
-    SubBmp24_Raw.Create(16, 16, 24, false, TempBytes, 64);
+    SubBmp24_Raw.Create(16, 16, PLPixelFormat::R8G8B8, TempBytes, 64);
     testBmpBase(SubBmp24_Raw);
 
     cerr << "  Testing 16 bpp PLSubBmp...\n";
@@ -205,7 +141,7 @@ void PLTester::RunTests ()
     SubBmp16.Create(m_AnyBmp16, PLRect(1, 1, 4, 4));
     testBmpBase(SubBmp16);
     PLSubBmp SubBmp16_Raw;
-    SubBmp16_Raw.Create(16, 16, 16, false, TempBytes, 32);
+    SubBmp16_Raw.Create(16, 16, PLPixelFormat::X1R5G5B5, TempBytes, 32);
     testBmpBase(SubBmp16_Raw);
 
     cerr << "  Testing 8 bpp PLSubBmp...\n";
@@ -213,7 +149,7 @@ void PLTester::RunTests ()
     SubBmp8.Create(m_AnyBmp8, PLRect(0, 0, 5, 5));
     testBmpBase(SubBmp8);
     PLSubBmp SubBmp8_Raw;
-    SubBmp8_Raw.Create(16, 16, 8, false, TempBytes, 128);
+    SubBmp8_Raw.Create(16, 16, PLPixelFormat::L8, TempBytes, 128);
     testBmpBase(SubBmp8_Raw);
 
     cerr << "  Testing pixel classes...\n";
@@ -256,12 +192,12 @@ void PLTester::RunTests ()
     cerr << "Skipping TIFF Codec check - support not compiled into library.\n";
 #endif
 #ifdef PL_SUPPORT_PNG
-    cerr << "Testing PNG Codec without compression...\n";
-    testCodec (PLPNGEncoder(), PLPNGDecoder());
-    cerr << "Testing PNG Codec with compression...\n";
-    PLPNGEncoder encoder;
-    encoder.SetCompressionLevel(9);
-    testCodec (encoder, PLPNGDecoder());
+//    cerr << "Testing PNG Codec without compression...\n";
+//    testCodec (PLPNGEncoder(), PLPNGDecoder());
+//    cerr << "Testing PNG Codec with compression...\n";
+//    PLPNGEncoder encoder;
+//    encoder.SetCompressionLevel(9);
+//    testCodec (encoder, PLPNGDecoder());
 
 #else
     cerr << "Skipping PNG Codec check - support not compiled into library.\n";
@@ -295,7 +231,8 @@ void PLTester::RunTests ()
 #endif    
 
     cerr << "Testing Filters...\n";
-    PLTestFilters FilterTest(&m_AnyBmp32, &m_AnyBmp8);
+    setUp();
+    PLTestFilters FilterTest(&m_AnyBmp32, &m_AnyBmp24, &m_AnyBmp16, &m_AnyBmp8);
     FilterTest.RunTests();
     AggregateStatistics (FilterTest);
     if (!FilterTest.IsOk())
@@ -312,7 +249,6 @@ void PLTester::RunTests ()
     // TODO:
     // - JPEG Codec test.
     // - Codec tests using CMemSource and PLMemSink.
-    // - DirectDraw bmp tests.
     // - More error handling tests (libcurl errors,...).
 
   }
@@ -338,7 +274,7 @@ void PLTester::testBmpBase(PLBmpBase& Bmp)
     cerr << "    Testing copy constructors...\n";
     PLAnyBmp AnyBmp (Bmp);
     Test (Bmp == AnyBmp);
-#ifdef _WINDOWS
+#ifdef _WIN32
     PLWinBmp WinBmp (Bmp);
     Test (Bmp == WinBmp);
 
@@ -346,34 +282,20 @@ void PLTester::testBmpBase(PLBmpBase& Bmp)
     Test (Bmp == DIBSect);
 
 #endif
-#ifdef PL_SUPPORT_SDL
-    if (Bmp.GetBitsPerPixel() == 32) 
-    {
-      PLSDLBmp SDLBmp (Bmp);
-      Test (Bmp == SDLBmp);
-    }
-#endif    
+  
   }
   {
     cerr << "    Testing assignment operators...\n";
     PLAnyBmp AnyBmp;
     AnyBmp = Bmp;
     Test (Bmp == AnyBmp);
-#ifdef _WINDOWS
+#ifdef _WIN32
     PLWinBmp WinBmp;
     PLDIBSection DIBSect;
     WinBmp = Bmp;
     Test (Bmp == WinBmp);
     DIBSect = Bmp;
     Test (Bmp == DIBSect);
-#endif
-#ifdef PL_SUPPORT_SDL
-    if (Bmp.GetBitsPerPixel() == 32) 
-    {
-      PLSDLBmp SDLBmp;
-      SDLBmp = Bmp;
-      Test (Bmp == SDLBmp);
-    }
 #endif
   }
   // Misc. tests
@@ -406,46 +328,28 @@ void PLTester::testPLBmp (PLBmp& Bmp)
     if (Bmp.GetBitsPerPixel() == 32)
     {
       cerr << "    Testing CreateCopy()...\n";
+      PLAnyBmp AnyBmp8;
       PLAnyBmp AnyBmp16;
       PLAnyBmp AnyBmp24;
       PLAnyBmp AnyBmp32;
-      AnyBmp24.CreateCopy (Bmp, 24);
-      AnyBmp32.CreateCopy (AnyBmp24, 32);
-      Bmp.CreateCopy (AnyBmp32, 32);
+      AnyBmp24.CreateCopy (Bmp, PLPixelFormat::R8G8B8);
+      AnyBmp32.CreateCopy (AnyBmp24, PLPixelFormat::X8R8G8B8);
 //      AnyBmp32.CreateCopy (Bmp);
 //      Bmp.CreateCopy (AnyBmp32, 32);
       Test (AnyBmp32 == Bmp);
 
-      AnyBmp16.CreateCopy (Bmp, 16);
-      AnyBmp32.CreateCopy (AnyBmp16, 32);
+      AnyBmp16.CreateCopy (Bmp, PLPixelFormat::X1R5G5B5);
+      AnyBmp32.CreateCopy (AnyBmp16, PLPixelFormat::X8R8G8B8);
+      Test (AnyBmp32.AlmostEqual(Bmp, 8));
+
+      AnyBmp8.CreateCopy (Bmp, PLPixelFormat::I8);
+      AnyBmp32.CreateCopy (AnyBmp8, PLPixelFormat::X8R8G8B8);
       Test (AnyBmp32.AlmostEqual(Bmp, 8));
     }
   }
 }
 
-#ifdef PL_SUPPORT_SDL
-void PLTester::testPLSDLBmp ()
-{
-  cerr << "    Testing Attach()...\n";
-#if SDL_BYTEORDER == SDL_BIG_ENDIAN
-  int rmask = 0xff000000;
-  int gmask = 0x00ff0000;
-  int bmask = 0x0000ff00;
-  int amask = 0x000000ff;
-#else
-  int rmask = 0x000000ff;
-  int gmask = 0x0000ff00;
-  int bmask = 0x00ff0000;
-  int amask = 0xff000000;
-#endif
-  SDL_Surface * pSurface = SDL_CreateRGBSurface (SDL_SWSURFACE, 10, 10, 32,
-          rmask, gmask, bmask, amask);
-  PLSDLBmp Bmp;
-  Bmp.Attach(pSurface);
-}
-#endif
-
-#ifdef _WINDOWS
+#ifdef _WIN32
 void PLTester::testPLWinBmp (PLWinBmp& Bmp)
 {
   // Test clipboard
@@ -629,6 +533,7 @@ void PLTester::testPoint ()
   PLASSERT (pt1-pt2 == PLPoint (2,2));
 
   PLASSERT (PLPoint (2,2)/2 == PLPoint (1,1));
+  PLASSERT (PLPoint (1,1)*2 == PLPoint (2,2));
 }
 
 void PLTester::testRect ()
@@ -691,7 +596,7 @@ void PLTester::testCodec (const PLPicEncoder& Encoder, const PLPicDecoder& Decod
 #endif
   cerr << "  Testing 8 bpp PLAnyBmp....\n";
   testCodecBmp (m_AnyBmp8, Encoder, Decoder, "test");
-#ifdef _WINDOWS
+#ifdef _WIN32
   cerr << "  Testing 32 bpp PLDIBSection....\n";
   testCodecBmp (m_DIBSect32, Encoder, Decoder, "test");
   cerr << "  Testing 8 bpp PLDIBSection....\n";
@@ -702,9 +607,9 @@ void PLTester::testCodec (const PLPicEncoder& Encoder, const PLPicDecoder& Decod
   cerr << "  Testing bit-depth conversion....\n";
   PLAnyBmp NewBmp;
   const_cast<PLPicEncoder&>(Encoder).MakeFileFromBmp ("test", &m_AnyBmp8);
-  const_cast<PLPicDecoder&>(Decoder).MakeBmpFromFile ("test", &NewBmp, 32);
+  const_cast<PLPicDecoder&>(Decoder).MakeBmpFromFile ("test", &NewBmp, PLPixelFormat::X8R8G8B8);
   PLAnyBmp Bmp32;
-  Bmp32.CreateCopy (m_AnyBmp8, 32);
+  Bmp32.CreateCopy (m_AnyBmp8, PLPixelFormat::X8R8G8B8);
   Test (NewBmp == Bmp32);
 }
 
@@ -717,12 +622,11 @@ void PLTester::testCodecBmp (PLBmp& Bmp, const PLPicEncoder& Encoder,
   const_cast<PLPicEncoder&>(Encoder).MakeFileFromBmp (pszFName, &Bmp);
   const_cast<PLPicDecoder&>(Decoder).MakeBmpFromFile (pszFName, &NewBmp);
   ::remove (pszFName);  // Delete file again.
-  if (Bmp.GetBitsPerPixel() == 24)
-  {
-    PLAnyBmp TempBmp;
-    TempBmp.CreateCopy (Bmp, 32);
-    Bmp = TempBmp;
-  }
+    
+  PLAnyBmp TempBmp;
+  TempBmp.CreateCopy (NewBmp, Bmp.GetPixelFormat());
+  NewBmp = TempBmp;
+
   Test (Bmp == NewBmp);
 
   // Test writing to memory.
@@ -733,14 +637,11 @@ void PLTester::testCodecBmp (PLBmp& Bmp, const PLPicEncoder& Encoder,
   const_cast<PLPicDecoder&>(Decoder).MakeBmpFromMemory (
       MemSink.GetBytes(), Size, &Bmp);
   MemSink.Close();
-  if (Bmp.GetBitsPerPixel() == 24)
-  {
-    PLAnyBmp TempBmp;
-    TempBmp.CreateCopy (Bmp, 32);
-    Bmp = TempBmp;
-  }
-  Test (Bmp == NewBmp);
 
+  TempBmp.CreateCopy (NewBmp, Bmp.GetPixelFormat());
+  NewBmp = TempBmp;
+
+  Test (Bmp == NewBmp);
 }
 
 #ifdef PL_SUPPORT_TIFF
@@ -771,16 +672,16 @@ void PLTester::testCTIFFEx (PLBmp& Bmp)
 #endif
 
 
-void PLTester::setUpBmp (PLBmp& Bmp, int BPP)
+void PLTester::setUpBmp (PLBmp& Bmp, const PLPixelFormat & pf)
 {
-  Bmp.Create(5, 5, BPP, false, false);
+  Bmp.Create(5, 5, pf);
   Bmp.SetResolution (PLPoint (72, 72));
   PLBYTE ** ppLines = Bmp.GetLineArray();
   int y,x;
   for (y=0; y<5; y++)
     for (x=0; x<5; x++)
     {
-      switch (BPP)
+      switch (pf.GetBitsPerPixel())
       {
         case 8:
           if (y<2)
@@ -837,7 +738,7 @@ void PLTester::setUpBmp (PLBmp& Bmp, int BPP)
       }
     }
 
-  if (BPP == 8)
+  if (pf == PLPixelFormat::I8)
   {
     for (int i=0; i< 256; ++i)
     {
@@ -849,13 +750,13 @@ void PLTester::setUpBmp (PLBmp& Bmp, int BPP)
 
 void PLTester::setUp ()
 {
-  setUpBmp (m_AnyBmp32, 32);
-  setUpBmp (m_AnyBmp24, 24);
-  setUpBmp (m_AnyBmp16, 16);
-  setUpBmp (m_AnyBmp8, 8);
-#ifdef _WINDOWS
-  setUpBmp (m_DIBSect32, 32);
-  setUpBmp (m_DIBSect8, 8);
+  setUpBmp (m_AnyBmp32, PLPixelFormat::X8R8G8B8);
+  setUpBmp (m_AnyBmp24, PLPixelFormat::R8G8B8);
+  setUpBmp (m_AnyBmp16, PLPixelFormat::X1R5G5B5);
+  setUpBmp (m_AnyBmp8, PLPixelFormat::I8);
+#ifdef _WIN32
+  setUpBmp (m_DIBSect32, PLPixelFormat::X8R8G8B8);
+  setUpBmp (m_DIBSect8, PLPixelFormat::I8);
 //  setUpBmp (m_DDBmp32, 32);
 //  setUpBmp (m_DDBmp8, 8);
 #endif
@@ -865,52 +766,6 @@ void PLTester::tearDown ()
 {
 }
 
-void PLTester::dumpBmp (PLBmp& bmp)
-{
-  cerr << "  Size: " << bmp.GetWidth() <<", " << bmp.GetHeight() << endl;
-  cerr << "  Pixel data: \n";
-
-  PLBYTE ** ppLines = bmp.GetLineArray();
-  int y,x;
-  for (y=0; y<bmp.GetHeight(); y++)
-  {
-    cerr << "    ";
-    for (x=0; x<bmp.GetWidth(); x++)
-    {
-      PLPixel32 pix;
-      switch (bmp.GetBitsPerPixel())
-      {
-        case 8:
-          cerr << ppLines[y][x];
-          break;
-        case 32:
-          pix = *((PLPixel32*)&(ppLines [y][x*4]));
-          cerr << "(" << pix.GetR() << "," << pix.GetG() << "," << pix.GetB ()
-                << "," << pix.GetA () << ")";
-          break;
-        default:
-          PLASSERT (false);
-      }
-    }
-    cerr << "\n";
-  }
-  if (bmp.GetBitsPerPixel() <= 8)
-  {
-    cerr << "    Palette:";
-    cerr << "      ";
-    PLPixel32 * pPal = bmp.GetPalette();
-    int i;
-    for (i=0; i<2; i++)
-      cerr << "(" << pPal[i].GetR() << "," << pPal[i].GetG() << "," <<
-        pPal[i].GetB () << "," << pPal[i].GetA ();
-    cerr << "..." ;
-    for (i=254; i<256; i++)
-      cerr << "(" << pPal[i].GetR() << "," << pPal[i].GetG() << "," <<
-        pPal[i].GetB () << "," << pPal[i].GetA ();
-  }
-  cerr << "\n";
-}
-
 bool PLTester::almostEqual (PLBmp& bmp1, PLBmp& bmp2, int epsilon)
 {
   return bmp1.AlmostEqual (bmp2, epsilon);
@@ -921,6 +776,37 @@ bool PLTester::almostEqual (PLBmp& bmp1, PLBmp& bmp2, int epsilon)
 /--------------------------------------------------------------------
 |
 |      $Log: pltester.cpp,v $
+|      Revision 1.74  2004/11/09 15:55:06  artcom
+|      changed #ifdef _WINDOWS to #ifdef _WIN32 (since this is a macro that actually is predefined on  win32 platforms)
+|
+|      Revision 1.73  2004/10/02 22:23:13  uzadow
+|      - configure and Makefile cleanups\n- Pixelformat enhancements for several filters\n- Added PLBmpBase:Dump\n- Added PLBmpBase::GetPixelNn()-methods\n- Changed default unix byte order to BGR
+|
+|      Revision 1.72  2004/09/21 13:03:05  uzadow
+|      Reenabled testFlipRGB, added 32-bit version of PLFilterColorize.
+|
+|      Revision 1.71  2004/09/15 14:52:09  artcom
+|      - added PLPixelformatTest
+|      - added DICOM Decoder
+|
+|      Revision 1.70  2004/09/11 12:41:36  uzadow
+|      removed plstdpch.h
+|
+|      Revision 1.69  2004/09/11 10:30:40  uzadow
+|      Linux build fixes, automake dependency fixes.
+|
+|      Revision 1.68  2004/09/09 16:52:50  artcom
+|      refactored PixelFormat
+|
+|      Revision 1.67  2004/07/28 11:41:08  uzadow
+|      PNG decoder now decodes directly to 24 bpp
+|
+|      Revision 1.66  2004/06/20 16:59:38  uzadow
+|      Added PLBmpBase::CopyPixels() and PLInPlaceFilter
+|
+|      Revision 1.65  2004/06/19 16:49:11  uzadow
+|      Changed GetImage so it works with PLBmpBase
+|
 |      Revision 1.64  2004/06/15 14:17:25  uzadow
 |      First working version of PLSubBmp.
 |
