@@ -1,7 +1,7 @@
 /*
 /--------------------------------------------------------------------
 |
-|      $Id: plwinbmp.cpp,v 1.2 2002/08/04 20:08:01 uzadow Exp $
+|      $Id: plwinbmp.cpp,v 1.5 2004/09/11 12:41:37 uzadow Exp $
 |      Device independent bitmap class
 |
 |        Windows version
@@ -22,7 +22,6 @@
 \--------------------------------------------------------------------
 */
 
-#include "plstdpch.h"
 #include "plwinbmp.h"
 #include "plexcept.h"
 
@@ -35,7 +34,7 @@ PLWinBmp::PLWinBmp ()
     m_pBits (NULL)
 // Creates an empty bitmap.
 {
-  internalCreate(16, 16, 8, false, false);
+  internalCreate(16, 16, PLPixelFormat::I8);
 
   PLASSERT_VALID(this);
 }
@@ -60,17 +59,14 @@ void PLWinBmp::AssertValid () const
   // Bitmapinfo must equal member variables
   PLASSERT (m_pBMI->biHeight == m_Size.y);
   PLASSERT (m_pBMI->biWidth == m_Size.x);
-  PLASSERT (m_pBMI->biBitCount == m_bpp);
+  PLASSERT (m_pBMI->biBitCount == GetBitsPerPixel());
 
   // Only uncompressed bitmaps allowed.
   PLASSERT (m_pBMI->biCompression == BI_RGB);
 
   // No optimized color tables allowed.
   PLASSERT (m_pBMI->biClrUsed == 0 ||
-          m_pBMI->biClrUsed == (DWORD)(1 << m_bpp));
-
-  // Bits are always accessible
-  PLASSERT (m_LockCount >= 1);
+          m_pBMI->biClrUsed == (DWORD)(1 << GetBitsPerPixel()));
 }
 #endif
 
@@ -100,7 +96,7 @@ void PLWinBmp::AlphaBlt (PLWinBmp * pSrPLBmp, int x, int y)
   int miny = max (0,-y);
   int minx = max (0,-x);
 
-  if (pSrPLBmp->m_bAlphaChannel)
+  if (pSrPLBmp->HasAlpha())
   {
     int alpha, negalpha;
 
@@ -182,8 +178,8 @@ long PLWinBmp::GetBytesPerLine ()
 // Returns number of bytes used per line.
 {
   // bdelmee code change
-  int nBytes = m_Size.x*m_bpp / 8;
-  if (m_bpp == 1 && m_Size.x % 8)
+  int nBytes = m_Size.x*GetBitsPerPixel() / 8;
+  if (GetBitsPerPixel() == 1 && m_Size.x % 8)
     ++nBytes;
   // adjust to nearest DWORD-multiple
   return (nBytes + 3) & ~3;
@@ -251,7 +247,7 @@ void PLWinBmp::CreateFromHBitmap(HBITMAP hBitMap)
 
   freeMembers ();
 
-  internalCreate(pBIH->biWidth, pBIH->biHeight, pBIH->biBitCount, false, false);
+  internalCreate(pBIH->biWidth, pBIH->biHeight, pixelFormatFromBMI(pBIH));
 
   rc = ::GetDIBits (hdc, hBitMap, 0, GetHeight(), GetBits(),
                     (BITMAPINFO *)GetBMI(), DIB_RGB_COLORS);
@@ -533,13 +529,12 @@ long PLWinBmp::GetMemNeeded (LONG width, LONG height, WORD BitsPerPixel)
 /////////////////////////////////////////////////////////////////////
 // Protected callbacks
 
-void PLWinBmp::internalCreate (LONG Width, LONG Height, WORD BitsPerPixel,
-                              bool bAlphaChannel, bool bIsGreyscale)
+void PLWinBmp::internalCreate (LONG Width, LONG Height, const PLPixelFormat& pf)
 // Create a new empty DIB. Bits are uninitialized.
 // Assumes that no memory is allocated before the call.
 {
   // Allocate memory
-  int MemNeeded = GetMemNeeded (Width, Height, BitsPerPixel);
+  int MemNeeded = GetMemNeeded (Width, Height, pf.GetBitsPerPixel());
 
 #ifdef MAX_BITMAP_SIZE
   if (MemNeeded > MAX_BITMAP_SIZE)
@@ -555,7 +550,7 @@ void PLWinBmp::internalCreate (LONG Width, LONG Height, WORD BitsPerPixel,
   m_pBMI->biWidth = Width;
   m_pBMI->biHeight = Height;
   m_pBMI->biPlanes = 1;
-  m_pBMI->biBitCount = BitsPerPixel;
+  m_pBMI->biBitCount = pf.GetBitsPerPixel();
   m_pBMI->biCompression = BI_RGB;   // No compression
   m_pBMI->biSizeImage = 0;
   m_pBMI->biXPelsPerMeter = 0;
@@ -563,13 +558,9 @@ void PLWinBmp::internalCreate (LONG Width, LONG Height, WORD BitsPerPixel,
   m_pBMI->biClrUsed = 0;           // Always use the whole palette.
   m_pBMI->biClrImportant = 0;
 
-  Lock (true, true);
-
   // Set color table pointer & pointer to bits.
   initPointers ();
-
-  initLocals (Width, Height, BitsPerPixel, bAlphaChannel, bIsGreyscale);
-
+  initLocals (Width, Height, pf);
 
   PLASSERT_VALID (this);
 }
@@ -593,13 +584,11 @@ void PLWinBmp::internalCreate (BITMAPINFOHEADER* pBMI)
     throw (PLTextException (PL_ERRNO_MEMORY, "Out of memory creating bitmap."));
 
 	memcpy (m_pBMI, pBMI, MemNeeded);
-  Lock (true, true);
 
   // Set color table pointer & pointer to bits.
   initPointers ();
 
-  initLocals (m_pBMI->biWidth, m_pBMI->biHeight,
-              m_pBMI->biBitCount, false, false);
+  initLocals (m_pBMI->biWidth, m_pBMI->biHeight, pixelFormatFromBMI(m_pBMI));
 
   PLASSERT_VALID (this);
 }
@@ -612,8 +601,6 @@ void PLWinBmp::freeMembers ()
 
   delete [] m_pLineArray;
   m_pLineArray = NULL;
-
-  Unlock();
 }
 
 
@@ -666,6 +653,23 @@ void PLWinBmp::initPointers ()
   }
 }
 
+const PLPixelFormat& PLWinBmp::pixelFormatFromBMI(const BITMAPINFOHEADER * pBMI) const
+{
+  switch(pBMI->biBitCount) 
+  {
+    case 1:
+      return PLPixelFormat::L1;
+    case 8:
+      return PLPixelFormat::I8;
+    case 16:
+      return PLPixelFormat::X1R5G5B5;
+    case 24:
+      return PLPixelFormat::R8G8B8;
+    case 32:
+      return PLPixelFormat::X8R8G8B8;
+  }
+  return PLPixelFormat::DONTCARE;
+}
 
 BYTE * PLWinBmp::GetBits ()
 {
@@ -676,6 +680,15 @@ BYTE * PLWinBmp::GetBits ()
 /--------------------------------------------------------------------
 |
 |      $Log: plwinbmp.cpp,v $
+|      Revision 1.5  2004/09/11 12:41:37  uzadow
+|      removed plstdpch.h
+|
+|      Revision 1.4  2004/09/09 16:52:50  artcom
+|      refactored PixelFormat
+|
+|      Revision 1.3  2004/06/19 17:04:22  uzadow
+|      Removed Lock(), Unlock(), PLDDrawBmp
+|
 |      Revision 1.2  2002/08/04 20:08:01  uzadow
 |      Added PLBmpInfo class, ability to extract metainformation from images without loading the whole image and proper greyscale support.
 |
