@@ -1,7 +1,7 @@
 /*
 /--------------------------------------------------------------------
 |
-|      $Id: View.cpp,v 1.30 2002/03/29 19:18:23 uzadow Exp $
+|      $Id: View.cpp,v 1.31 2004/09/11 12:41:37 uzadow Exp $
 |       view class implementation
 |
 |      In the document/view model, this is where document rendering
@@ -201,7 +201,7 @@ void CPLView::OnDraw(CDC* pDC)
     int nStretchMode = COLORONCOLOR;
     int nScreenBPP   = thisApp.GetScreenBPP();
     // when in 256-color mode, see how haltoning performs
-    if ( m_bDither && nScreenBPP <= 8 && nScreenBPP < pDib->GetBitsPerPixel() )
+    if ( m_bDither && nScreenBPP <= 8 && nScreenBPP < (int)pDib->GetBitsPerPixel() )
       nStretchMode = HALFTONE;
 
     pDib->DrawEx(
@@ -899,6 +899,9 @@ void CPLView::applyFilterAndShow (PLFilter * pFilter)
 /--------------------------------------------------------------------
 |
 |      $Log: View.cpp,v $
+|      Revision 1.31  2004/09/11 12:41:37  uzadow
+|      removed plstdpch.h
+|
 |      Revision 1.30  2002/03/29 19:18:23  uzadow
 |      Fixed bug in crop dialog.
 |
